How to cite
===========

If you use this software in a scientific publication, we'd very much appreciate if you could cite the following paper:

- Smaï, F., and Wawrzyniak, P., 2020.
  Razorback, an open source Python library for robust processing of magnetotelluric data.
  Frontiers in Earth Science.
  https://doi.org/10.3389/feart.2020.00296
